"use client";
import Image from "next/image";

import { MapPin } from "lucide-react";

import { useUserInfo } from "@/servers/data/use-userinfo";
import { useTranslations } from "next-intl";
import { useState } from "react";
import AccountForm from "./account-form";
import ProgressInformation from "./progress-information";
import AccountInformation from "./user-info-section";


const AccountInformationMobile = ({
	className = "",
	userName,
	phoneNumber,
	location,
}: {
	userName: string;
	phoneNumber: string;
	location: string;
	className?: string;
}) => {
	return (
		<div
			className={`relative mt-8 flex w-full flex-col items-center ${className}`}
		>
			<Image
				src={"/images/profile/user-profile.jpg"}
				alt="user image"
				width={190}
				height={190}
				style={{ width: "190px", height: "190px" }}
				className="relative z-50 rounded-full object-cover"
			/>

			<div className="my-4 flex flex-col items-center gap-4">
				<p className="text-lg font-semibold text-custom-fourth">{userName}</p>
				<div className="flex w-full items-center justify-between gap-4">
					<div className="flex items-center gap-2">
						<p className="text-sm text-custom-fifth">{phoneNumber}</p>
						<MapPin color="#3D475C" size={"16px"} />
					</div>
					<div className="flex items-center gap-2">
						<p className="text-sm text-custom-fifth">{location}</p>
						<MapPin color="#3D475C" size={"16px"} />
					</div>
				</div>
			</div>
		</div>
	);
};

function AccountInformationComponent({ accountForm = true }: { accountForm?: boolean }) {
	const t = useTranslations("UserAccount");
	const { userInfo, refetch } = useUserInfo();
	const [imageFile, setImageFile] = useState<File | null>(null);

	const mockData = {
		points: 3000,
		userName: t("UserName"),
		phoneNumber: "12312412412",
		location: t("GeographicalLocation"),
		progress: 60,
	};

	return (
		<>

			<div className="flex flex-col-reverse justify-between md:flex-row">
				<ProgressInformation user={userInfo} />
				<AccountInformation setImageFile={setImageFile} />
			</div>
			<div className="my-12 -mr-12 h-[1px] w-[400%] bg-[#DEE2E6]" />

			{accountForm && <AccountForm imageFile={imageFile} userInfo={userInfo} refetch={refetch} />}

			<AccountInformationMobile
				userName={mockData.userName}
				phoneNumber={mockData.phoneNumber}
				location={mockData.location}
				className="flex md:hidden"
			/>
		</>
	);
}

export default AccountInformationComponent;
